@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11286 2018-11-30 08:48:45Z Kevin $
+# $Id: __init__.py 11631 2019-06-11 20:19:44Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Kevin $ (last)
-# $Date: 2018-11-30 16:48:45 +0800 (週五, 30 十一月 2018) $
-# $Revision: 11286 $
+# $Author: Lavender $ (last)
+# $Date: 2019-06-12 05:19:44 +0900 (週三, 12 六月 2019) $
+# $Revision: 11631 $
 
 # Avoid conflict with Iuno.cloud.logging moudle.
 from __future__ import absolute_import
@@ -114,7 +114,8 @@ class LocalCacheProvider(singletonmixin.Singleton):
 localCache = LocalCacheProvider.getInstance()
 
 def attachSettings(settingsLocals, services=(
-                    'queue', 'mail', 'logging', 'browser', 'storage'),
+                    'queue', 'mail', 'logging', 
+                    'browser', 'storage', 'metrics'),
                    serviceSettings=None,
                    loggingFile=None, loggingLevel=None,
                    cache=False, cacheDir=None):
