@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11780 2019-11-19 10:53:34Z Lavender $
+# $Id: __init__.py 11783 2019-11-26 12:19:42Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2019-11-19 19:53:34 +0900 (週二, 19 十一月 2019) $
-# $Revision: 11780 $
+# $Date: 2019-11-26 21:19:42 +0900 (週二, 26 十一月 2019) $
+# $Revision: 11783 $
 
 import os
 import sys
@@ -426,7 +426,11 @@ def attachSettings(settingsDict, enablePaypal=False):
                                             
     # bonus
     for s in settingsDict['OSCAR_DASHBOARD_NAVIGATION']:
-        if s.get('icon') == 'icon-bullhorn': # icon
+        addUrl = False
+        for child in s.get('children', []):
+            if child.get('url_name') == 'dashboard:voucher-list':
+                addUrl = True
+        if addUrl:
             s['children'].append({
                 'label': _('Bonus settings'),
                 'url_name': 'bonusSettings',
