@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 11780 2019-11-19 10:53:34Z Lavender $
+# $Id: views.py 11783 2019-11-26 12:19:42Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-11-19 19:53:34 +0900 (週二, 19 十一月 2019) $
-# $Revision: 11780 $ 
+# $Date: 2019-11-26 21:19:42 +0900 (週二, 26 十一月 2019) $
+# $Revision: 11783 $ 
 
 import json
 import logging
@@ -22,6 +22,7 @@ import datetime
 import base64
 import urllib
 import six
+import re
 
 from collections import OrderedDict
 
@@ -81,6 +82,8 @@ fileHandler = logging.FileHandler('Payment.log')
 fileHandler.setLevel(logging.WARNING)
 logger.addHandler(fileHandler)
 
+BONUS_VOUCHER_CODE = r"^BONUS-\d*-\d*-[a-fA-F\d]{32}$"
+
 DEVELOPMENT = 1
 
 SPGATEWAY = 'spgateway'
@@ -273,7 +276,10 @@ def placeOrder(self, basket, total,  # noqa (too complex (12))
             config = BonusSettings.objects.get(id=1)
             
             # receive
-            consumption = int(total.excl_tax) - config.consumption 
+            consumption = (
+                int(total.excl_tax) - config.consumption - 
+                int(shipping_charge.excl_tax))
+            
             receive = 0
             if consumption >= 0:
                 # config.percent / 100 = X %
@@ -283,7 +289,7 @@ def placeOrder(self, basket, total,  # noqa (too complex (12))
             use = 0
             bonusVoucher = None
             for v in basket.vouchers.all():
-                if v.code.startswith("BONUS"):
+                if re.match(BONUS_VOUCHER_CODE, v.code):
                     bonusVoucher = v
               
             # len(BONUS-[bouns use]-[bouns discount]-XXXX.split("-")) == 4
@@ -486,9 +492,13 @@ class BonusSettingsView(generic.TemplateView):
     def post(self, request, *args, **kwargs):
         config, created = BonusSettings.objects.get_or_create(id=1)  
         form = forms.BonusSettingsForm(request.POST, instance=config)
-        form.save()
-        messages.success(request, _("Settings saved"))
-        return redirect("bonusSettings")
+        if form.is_valid():
+            form.save()
+            messages.success(request, _("Settings saved"))
+            return redirect("bonusSettings")
+        else:
+            messages.error(request, _("Form error"))
+            return render(request, self.template_name, self.get_context_data())
         
 from oscar.apps.basket import views as basketViews
 
@@ -518,12 +528,12 @@ def voucherRemoveViewPost(self, request, *args, **kwargs):
             request, _("No voucher found with id '%s'") % voucher_id)
     else:
         request.basket.vouchers.remove(voucher)
-        self.remove_signal.send(
-            sender=self, basket=request.basket, voucher=voucher)
         if voucher.code.startswith("BONUS"):
             messages.info(
                 request, _("Bouns discount removed from basket"))
         else:
+            self.remove_signal.send(
+                sender=self, basket=request.basket, voucher=voucher)
             messages.info(
                 request, _("Voucher '%s' removed from basket") % voucher.code)
 
@@ -546,10 +556,10 @@ def useBonus(request):
     b, created = Bonus.objects.get_or_create(user=request.user)
     config, created = BonusSettings.objects.get_or_create(id=1)
     
-    if quantity >= b.quantity:
+    if quantity > b.quantity:
         messages.error(request, _("Not enough bonus."))
         return redirect("basket:summary")
-    if quantity >= config.limit:
+    if not config.limit == -1 and quantity > config.limit:
         messages.error(
             request, _("Use bonus over the upper limit %s.") % config.limit)
         return redirect("basket:summary")
@@ -557,10 +567,13 @@ def useBonus(request):
     value = quantity * config.discount
     
     # create voucher
-    range, created = Range.objects.get_or_create(
-        name=_("All Products"),
-        includes_all_products=True,
-    )
+    if Range.objects.filter(includes_all_products=True).exists():
+        range = Range.objects.filter(includes_all_products=True).first()
+    else:
+        range, created = Range.objects.get_or_create(
+            name=_("All Products"),
+            includes_all_products=True,
+        )
     if Condition.objects.filter(
         range=range, type=Condition.COUNT, value=1).exists():
         condition = Condition.objects.filter(
@@ -583,8 +596,8 @@ def useBonus(request):
             value=value
         )
     
-    name = _("Bouns discount %(value)d for %(username)s") % {
-        'value': value, 'username': request.user.username}
+    name = _("Bouns %(quantity)d discount %(value)d for %(username)s") % {
+        'value': value, 'username': request.user.username, 'quantity': quantity}
     offer, created = ConditionalOffer.objects.get_or_create(
         name=_("Offer for voucher '%s'") % name,
         offer_type=ConditionalOffer.VOUCHER,
@@ -607,7 +620,7 @@ def useBonus(request):
     
     # add voucher
     for v in request.basket.vouchers.all():
-        if v.code.startswith("BONUS"):
+        if re.match(BONUS_VOUCHER_CODE, v.code):
             request.basket.vouchers.remove(v)
     request.basket.vouchers.add(voucher)
         
